==> nextcloud-app-contacts-3.5.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/zh_HK.js <==
OC.L10N.register(
    "contacts",
    {
    "All contacts" : "所有聯絡人",
    "Details" : "詳細資料",
    "Contacts" : "通訊錄",
    "A contacts app for Nextcloud" : "Nextcloud 的通訊錄應用程式",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 通訊錄應用程式是 Nextcloud 的 CardDAV 伺服器的用戶界介面。可輕鬆使用您的 Nextcloud 同步各個裝置上的聯絡人，並在線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 目前有電子郵件與日曆，還會有更多。\n* 🎉 **不會忘記生日！** 您可以將生日與其他重複的活動與您的 Nextcloud 日曆同步。\n* 👥 **分享通訊錄！** 您想與您的朋友或同事分享您的聯絡人嗎？沒問題！\n* 🙈 **我們沒有無謂地重複開發！** 以超棒且開放的 SabreDAV 函式庫為基礎。",
    "Copy to full name" : "複製到全名",
    "Omit year" : "省略年份",
    "Allow updating avatars from social media" : "允許從社群媒體更新大頭照",
    "Add new property" : "新增屬性",
    "Choose property type" : "選擇屬性類型",
    "Upload a new picture" : "上傳一張新的圖片",
    "Choose from Files" : "從檔案選取",
    "Get from " : "取自",
    "Download picture" : "下載圖片",
    "Delete picture" : "刪除圖片",
    "Choose from files" : "選擇檔案",
    "Invalid image" : "圖像無效",
    "Image is too big (max 1MB)." : "圖像過大（最大 1MB）。",
    "Pick an avatar" : "選擇一個大頭照",
    "Error while processing the picture." : "處理相片時錯誤。",
    "Avatar downloaded from social network" : "從社群網路下載大頭照",
    "Avatar already up to date" : "大頭照已是最新",
    "Avatar download failed" : "大頭照下載失敗",
    "No contact selected" : "未選擇聯絡人",
    "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
    "Name" : "姓名",
    "Company" : "公司名稱",
    "Title" : "職銜",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
    "Download" : "下載",
    "Clone contact" : "複製聯絡人",
    "Generate QR Code" : "生成 QR Code",
    "Delete" : "刪除",
    "Contact vCard as qrcode" : "QR Code 形式的聯絡人 vCard",
    "Pick an address book" : "選取一個通訊錄",
    "Select address book" : "選擇通訊錄",
    "Cancel" : "取消",
    "This contact is not yet synced. Edit it to save it to the server." : "此聯絡人尚未同步。編輯它以將其儲存到伺服器。",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
    "Address book" : "通訊錄",
    "Groups" : "群組",
    "New contact" : "新聯絡人",
    "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
    "The contact doesn't exists anymore on the server." : "聯絡人不再存在於伺服器上。",
    "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
    "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
    "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
    "Remove {type}" : "移除 {type}",
    "Search {types}" : "搜尋 {types}",
    "Loading …" : "正在載入 …",
    "List is empty" : "列表是空的",
    "No results" : "沒有結果",
    "Add to group" : "新增至群組",
    "Add {type}" : "新增 {type}",
    "Select type" : "選擇類型",
    "Select Date" : "選擇日期",
    "Add contact in group" : "新增聯絡人到群組",
    "Last modified" : "上次修改",
    "Select option" : "選擇選項",
    "Rename" : "重新命名",
    "Enabled" : "已啟用",
    "Disabled" : "已停用",
    "Copied" : "已複製",
    "Can not copy" : "無法複製",
    "Copy link" : "複製連結",
    "Toggling of address book was not successful" : "通訊錄切換失敗",
    "This will delete the address book and every contacts within it" : "這將刪除通訊錄及其所有的聯絡人",
    "Delete {addressbook} ?" : "刪除 {addressbook}？",
    "Deletion of address book was not successful." : "刪除通訊錄失敗。",
    "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
    "Address book copied to clipboard" : "通訊錄已複製到剪貼板。",
    "Address book was not copied to clipboard." : "通訊錄未複製到剪貼板。",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
    "Share with users or groups" : "與用戶或群組分享",
    "No users or groups" : "沒有用戶或群組",
    "can edit" : "允許編輯",
    "Unable to delete the share" : "無法刪除這個分享",
    "Unable to change permissions" : "無法變更權限",
    "Import contacts" : "導入聯絡人",
    "Import into the {addressbookName} addressbook" : "導入至 {addressbookName} 通訊錄",
    "Select local file" : "選取本機檔案",
    "Import from files" : "從檔案導入",
    "Importing is disabled because there are no address books available" : "已停用導入，因為沒有可用的通訊錄",
    "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
    "Address book name" : "通訊錄名稱",
    "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
    "First name" : "名",
    "Last name" : "姓",
    "Phonetic first name" : "語音名",
    "Phonetic last name" : "語音姓",
    "Display name" : "顯示名稱",
    "Sort by {sorting}" : "按 {sorting} 排序",
    "Update avatars from social media" : "從社群媒體更新大頭照",
    "(refreshed once per week)" : "（每週重新整理一次）",
    "Add contacts" : "新增聯絡人",
    "+ New group" : "+ 新增群組",
    "Create a new group" : "建立新群組",
    "Group name" : "群組名稱",
    "Loading contacts …" : "正在載入聯絡人……",
    "There are no contacts yet" : "目前沒有聯絡人",
    "Create contact" : "建立聯絡人",
    "There are no contacts in this group" : "群組中沒有聯絡人",
    "Create contacts" : "建立聯絡人",
    "Not grouped" : "未歸類",
    "Recently contacted" : "最近聯絡",
    "Unable to create the contact." : "無法建立聯絡人",
    "Contact not found" : "找不到聯絡人",
    "Group not found" : "找不到群組",
    "This group already exists" : "該群組已存在",
    "Close" : "關閉",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
    "_{count} error_::_{count} errors_" : ["{count} 個錯誤"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在導入 %n 個聯絡人至 {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["完成導入 %n 個聯絡人至 {addressbook}"],
    "Import" : "導入",
    "Nickname" : "暱稱",
    "Detailed name" : "詳細名稱",
    "Additional names" : "別名/中間名",
    "Prefix" : "前綴",
    "Suffix" : "後綴",
    "Notes" : "備忘",
    "Website" : "網站",
    "Location" : "地點",
    "Federated Cloud ID" : "雲端聯邦 ID",
    "Home" : "家",
    "Work" : "業務",
    "Other" : "其他",
    "Address" : "地址",
    "Post office box" : "郵政信箱",
    "Extended address" : "擴展地址",
    "City" : "城市",
    "State or province" : "州或省",
    "Postal code" : "郵遞區號",
    "Country" : "國家",
    "Birthday" : "生日",
    "Anniversary" : "週年",
    "Date of death" : "卒日",
    "Email" : "電郵地址",
    "Instant messaging" : "即時通訊",
    "Phone" : "電話",
    "Mobile" : "手提電話",
    "Work mobile" : "手提電話（業務）",
    "Home mobile" : "手提電話（家）",
    "Fax" : "傳真",
    "Fax home" : "傳真（家）",
    "Fax work" : "傳真（業務）",
    "Pager" : "傳呼機",
    "Voice" : "語音",
    "Car" : "車子",
    "Work pager" : "傳呼機（業務）",
    "Social network" : "社交網絡",
    "Relationship to you" : "與您的關係",
    "Spouse" : "配偶",
    "Child" : "孩子 ",
    "Mother" : "母親",
    "Father" : "父親",
    "Parent" : "父母",
    "Brother" : "兄弟",
    "Sister" : "姊妹",
    "Relative" : "親屬",
    "Friend" : "朋友",
    "Colleague" : "同事",
    "Manager" : "上司",
    "Assistant" : "助理",
    "Related contacts" : "相關聯絡人",
    "Contact" : "聯絡人",
    "Agent" : "代理人",
    "Emergency" : "緊急",
    "Co-worker" : "同事",
    "Gender" : "性別",
    "Female" : "女性",
    "Male" : "男性",
    "None" : "無",
    "Unknown" : "不詳",
    "Timezone" : "時區",
    "Spoken languages" : "會說的語言",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 個聯絡人讀取失敗"],
    "Unable to delete contact" : "無法刪除聯絡人",
    "Your web browser is out of date" : "您的網路瀏覽器已過期",
    "This application is not compatible with Internet Explorer" : "此應用程式與 Internet Explorer 不相容"
},
"nplurals=1; plural=0;");

==> nextcloud-app-contacts-4.0.0-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/zh_HK.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "詳細資料",
    "All contacts" : "所有聯絡人",
    "Contacts" : "通訊錄",
    "A contacts app for Nextcloud" : "Nextcloud 的通訊錄應用程式",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 通訊錄應用程式是 Nextcloud 的 CardDAV 伺服器的用戶界介面。可輕鬆使用您的 Nextcloud 同步各個裝置上的聯絡人，並在線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 目前有電子郵件與日曆，還會有更多。\n* 🎉 **不會忘記生日！** 您可以將生日與其他重複的活動與您的 Nextcloud 日曆同步。\n* 👥 **分享通訊錄！** 您想與您的朋友或同事分享您的聯絡人嗎？沒問題！\n* 🙈 **我們沒有無謂地重複開發！** 以超棒且開放的 SabreDAV 函式庫為基礎。",
    "Copy to full name" : "複製到全名",
    "Omit year" : "省略年份",
    "Allow updating avatars from social media" : "允許從社群媒體更新大頭照",
    "Please select a circle" : "請選擇社交圈子",
    "Loading circle …" : "社交圈子加載中 ...",
    "Your request to join this circle is pending approval" : "您加入此圈子的請求正在等待批准",
    "You are not a member of {circle}" : "您不是 {circle} 的成員",
    "There was an error fetching the member list" : "擷取成員清單出錯",
    "Loading contacts …" : "正在載入通訊錄 …",
    "There are no contacts yet" : "目前沒有聯絡人",
    "Create contact" : "建立聯絡人",
    "There are no contacts in this group" : "群組中沒有聯絡人",
    "Create contacts" : "建立聯絡人",
    "Add contacts" : "新增聯絡人",
    "Loading …" : "正在載入 …",
    "Add member" : "添加成員",
    "Leave circle" : "離開社交圈子",
    "Delete circle" : "刪除社交圈子",
    "Download" : "下載",
    "Groups" : "群組",
    "Create a new group" : "建立新群組",
    "Group name" : "群組名稱",
    "Circles" : "社交圈子",
    "Create a new circle" : "創建新社交圈子",
    "Show all groups" : "顯示所有群組",
    "Collapse groups" : "收合群組",
    "Show all circles" : "顯示所有社交圈子",
    "Collapse circles" : "收合社交圈子",
    "This group already exists" : "該群組已存在",
    "This circle already exists" : "此社交圈子已存在",
    "An error happened during the creation of the circle" : "創建社交圈子的過程中發生錯誤",
    "Rename" : "重新命名",
    "Enabled" : "已啟用",
    "Disabled" : "已停用",
    "Delete" : "刪除",
    "Copied" : "已複製",
    "Cannot copy" : "無法複製",
    "Copy link" : "複製連結",
    "Toggling of address book was not successful" : "通訊錄切換失敗",
    "This will delete the address book and every contacts within it" : "這將刪除通訊錄及其所有的聯絡人",
    "Delete {addressbook}?" : "刪除 {addressbook}？",
    "Deletion of address book was not successful." : "刪除通訊錄失敗。",
    "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
    "Share with users or groups" : "與用戶或群組分享",
    "No users or groups" : "沒有用戶或群組",
    "can edit" : "允許編輯",
    "Unable to delete the share" : "無法刪除這個分享",
    "Unable to change permissions" : "無法變更權限",
    "Import contacts" : "導入聯絡人",
    "Import into the {addressbookName} address book" : "導入至 {addressbookName} 通訊錄",
    "Select local file" : "選擇本機檔案",
    "Import from Files" : "從檔案導入",
    "Importing is disabled because there are no address books available" : "已停用導入，因為沒有可用的通訊錄",
    "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
    "Address book name" : "通訊錄名稱",
    "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
    "First name" : "名",
    "Last name" : "姓",
    "Phonetic first name" : "語音名",
    "Phonetic last name" : "語音姓",
    "Display name" : "顯示名稱",
    "Last modified" : "上次修改",
    "Sort by {sorting}" : "按 {sorting} 排序",
    "Update avatars from social media" : "從社群媒體更新大頭照",
    "(refreshed once per week)" : "（每週重新整理一次）",
    "An error happened during the config change" : "配置更改期間發生錯誤",
    "Circle name" : "社交圈子名稱",
    "Circle owned by {owner}" : "{owner} 擁有的社交圈子",
    "Request to join" : "請求加入",
    "Description" : "描述",
    "There is no description for this circle" : "此社交圈子沒有任何描述",
    "Enter a description for the circle" : "輸入社交圈子的描述",
    "An error happened during description sync" : "描述同步期間發生錯誤",
    "An error happened during name sync" : "名稱同步期間發生錯誤",
    "Add new property" : "新增屬性",
    "Choose property type" : "選擇屬性類型",
    "Upload a new picture" : "上傳一張新的圖片",
    "Choose from Files" : "從檔案選取",
    "Get from " : "取自",
    "Download picture" : "下載圖片",
    "Delete picture" : "刪除圖片",
    "Invalid image" : "圖像無效",
    "Image is too big (max 1MB)." : "圖像過大（最大 1MB）。",
    "Pick an avatar" : "選擇一個大頭照",
    "Error while processing the picture." : "處理相片時錯誤。",
    "Avatar downloaded from social network" : "從社群網路下載大頭照",
    "Avatar already up to date" : "大頭照已是最新",
    "Avatar download failed" : "大頭照下載失敗",
    "No contact selected" : "未選擇聯絡人",
    "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
    "Name" : "姓名",
    "Company" : "公司名稱",
    "Title" : "職銜",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
    "Clone contact" : "複製聯絡人",
    "Generate QR Code" : "生成 QR Code",
    "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
    "Pick an address book" : "選取一個通訊錄",
    "Select address book" : "選擇通訊錄",
    "Cancel" : "取消",
    "This contact is not yet synced. Edit it to save it to the server." : "此聯絡人尚未同步。編輯它以將其儲存到伺服器。",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
    "Address book" : "通訊錄",
    "New contact" : "新聯絡人",
    "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
    "The contact doesn't exists anymore on the server." : "聯絡人不再存在於伺服器上。",
    "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
    "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
    "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
    "Add to {group}" : "新增至 {group]",
    "Remove {type}" : "移除 {type}",
    "Search {types}" : "搜尋 {types}",
    "Search for people to add" : "搜索要添加的人",
    "No results" : "沒有結果",
    "Add to group" : "新增至群組",
    "Add {type}" : "新增 {type}",
    "New circle name" : "新社交圈子名稱",
    "Personal circle" : "個人社交圈子",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "這個圈子只有你能看到。其他成員將無法看到或使用它。",
    "Local circle" : "近端社交圈子",
    "This circle will not be shared with the other instances of the global scale" : "此社交圈子不會與全球範圍內的其他實例共享",
    "Create circle" : "創建社交圈子",
    "Loading members list …" : "正在加載成員清單 …",
    "The list of members is only visible to members of this circle" : "成員列表僅此圈子的成員可見",
    "There is no member in this circle" : "此社交圈子中沒有任何成員",
    "Add members" : "添加成員",
    "Show circle details" : "顯示社交圈子細節",
    "Add to {circle}" : "添加到 {circle}",
    "Unable to get the recommendations list" : "無法獲取推薦列表",
    "Unable to get the results" : "無法得到結果",
    "Some members could not be added" : "部分成員無法添加",
    "There was an issue adding members to the circle" : "將成員添加到社交圈子時出現問題",
    "Accept membership request" : "接受會員申請",
    "Reject membership request" : "拒絕會員申請",
    "Manage level" : "管理程度",
    "Remove member" : "移除成員",
    "Pending" : "待定的",
    "Promote as sole owner" : "晉升作為唯一所有者",
    "Promote to {level}" : "晉升到 {level}",
    "Demote to {level}" : "降級到 {level}",
    "Could not delete the member {displayName}" : "不能刪除成員 {displayName}",
    "Could not change the member level to {level}" : "無法將成員級別更改為 {level}",
    "Could not accept membership request" : "無法接受成為成員的申請",
    "Select type" : "選擇類型",
    "Select Date" : "選擇日期",
    "Add contact in group" : "新增聯絡人到群組",
    "Select option" : "選擇選項",
    "Unable to create the contact." : "無法建立聯絡人",
    "Contact not found" : "找不到聯絡人",
    "Group {group} not found" : "找不到群組 {group}",
    "Close" : "關閉",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
    "_{count} error_::_{count} errors_" : ["{count} 個錯誤"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在導入 %n 個聯絡人至 {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["完成導入 %n 個聯絡人至 {addressbook}"],
    "Import" : "導入",
    "Could not copy" : "無法複製",
    "Join circle" : "加入社交圈子",
    "You are about to leave {circle}.\nAre you sure?" : "您即將離開 {circle}。\n你確定嗎？",
    "Please confirm circle leave" : "請確認您要離開此社交圈子",
    "Could not leave the circle {displayName}" : "不能退出社交圈子 {displayName}",
    "Unable to join the circle" : "無法加入社交圈子",
    "You are about to delete {circle}.\nAre you sure?" : "您即將刪除 {circle}。\n你確定嗎？",
    "Please confirm circle deletion" : "請確認社交圈子刪除",
    "Unable to delete the circle" : "無法刪除社交圈子",
    "Link copied to the clipboard" : "已複製連結至剪貼板",
    "Could not copy link to the clipboard." : "無法複製連結至剪貼板",
    "Not grouped" : "未歸類",
    "Recently contacted" : "最近聯絡",
    "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "社交圈子允許您在 Nextcloud 實例上與其他用戶創建群組並與他們分享。",
    "Circle" : "社交圈子",
    "User" : "用戶",
    "Group" : "群組",
    "Email" : "電郵地址",
    "Contact" : "聯絡人",
    "Member" : "成員",
    "Moderator" : "主持人",
    "Admin" : "管理員",
    "Owner" : "所有者",
    "Invites" : "邀請",
    "Anyone can request membership" : "任何人都可以申請加入",
    "Members need to accept invitation" : "會員需要接受邀請",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "會員資格必須由版主確認/接受（需要開放）",
    "Members can also invite" : "會員也可以邀請",
    "Visibility" : "可見性",
    "Visible to everyone" : "所有人都看得到",
    "Circle membership" : "社交圈子會員",
    "Prevent circle from being a member of another circle" : "防止社交圈子成為另一個圈子的成員",
    "Users" : "用戶",
    "Emails" : "電子郵件",
    "Nickname" : "暱稱",
    "Detailed name" : "詳細名稱",
    "Additional names" : "別名/中間名",
    "Prefix" : "前綴",
    "Suffix" : "後綴",
    "Notes" : "備忘",
    "Website" : "網站",
    "Location" : "地點",
    "Federated Cloud ID" : "雲端聯邦 ID",
    "Home" : "家",
    "Work" : "業務",
    "Other" : "其他",
    "Address" : "地址",
    "Post office box" : "郵政信箱",
    "Extended address" : "擴展地址",
    "City" : "城市",
    "State or province" : "州或省",
    "Postal code" : "郵遞區號",
    "Country" : "國家",
    "Birthday" : "生日",
    "Anniversary" : "週年",
    "Date of death" : "卒日",
    "Instant messaging" : "即時通訊",
    "Phone" : "電話",
    "Mobile" : "手提電話",
    "Work mobile" : "手提電話（業務）",
    "Home mobile" : "手提電話（家）",
    "Fax" : "傳真",
    "Fax home" : "傳真（家）",
    "Fax work" : "傳真（業務）",
    "Pager" : "傳呼機",
    "Voice" : "語音",
    "Car" : "車子",
    "Work pager" : "傳呼機（業務）",
    "Social network" : "社交網絡",
    "Relationship to you" : "與您的關係",
    "Spouse" : "配偶",
    "Child" : "孩子 ",
    "Mother" : "母親",
    "Father" : "父親",
    "Parent" : "父母",
    "Brother" : "兄弟",
    "Sister" : "姊妹",
    "Relative" : "親屬",
    "Friend" : "朋友",
    "Colleague" : "同事",
    "Manager" : "上司",
    "Assistant" : "助理",
    "Related contacts" : "相關聯絡人",
    "Agent" : "代理人",
    "Emergency" : "緊急",
    "Co-worker" : "同事",
    "Gender" : "性別",
    "Female" : "女性",
    "Male" : "男性",
    "None" : "無",
    "Unknown" : "不詳",
    "Timezone" : "時區",
    "Spoken languages" : "會說的語言",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 個聯絡人讀取失敗"],
    "Some circle(s) an error occurred. Check the console for more details." : "某些圈子出錯，請查看控制台以獲取更多詳細信息。",
    "Unable to create circle {circleName}" : "無法創建社交圈子 {circleName}",
    "Unable to delete circle {circleId}" : "無法刪除社交圈子 {circleId}",
    "Unable to delete contact" : "無法刪除聯絡人",
    "Your web browser is out of date" : "您的網路瀏覽器已過期",
    "This application is not compatible with Internet Explorer" : "此應用程式與 Internet Explorer 不相容"
},
"nplurals=1; plural=0;");
